==> http-requester-pure-java-0.1.0-alpha-sources.jar: requesterpj/internal/connection/provider/RequesterConnectionProvider.java <==
/*
 * (c) 2003-2022 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package requesterpj.internal.connection.provider;

import org.mule.runtime.api.connection.ConnectionValidationResult;
import org.mule.runtime.extension.api.annotation.param.Optional;
import org.mule.runtime.extension.api.annotation.param.Parameter;
import org.mule.runtime.extension.api.annotation.param.display.DisplayName;
import org.mule.runtime.extension.api.annotation.param.display.Summary;
import org.mule.runtime.http.api.HttpConstants;
import org.mule.runtime.http.api.client.HttpClient;
import org.mule.runtime.http.api.client.HttpRequestOptions;
import org.mule.runtime.http.api.domain.message.request.HttpRequest;

import com.mulesoft.connectivity.rest.commons.api.connection.RestConnectionProvider;

import requesterpj.internal.connection.RequesterConnection;

public class RequesterConnectionProvider extends RestConnectionProvider<RequesterConnection> {

    //TODO: We don't need this! Remove this... just have this as a field not marked as parameter with SDK
    @DisplayName("Base Uri")
    @Summary("Parameter base URI. Each instance or tenant gets its own base URI.")
    @Parameter
    @Optional
    private String baseUri;

    @Override public String getBaseUri() {
        return baseUri;
    }

    @Override
    protected RequesterConnection createConnection(HttpClient httpClient, HttpRequestOptions httpRequestOptions) {
        return new RequesterConnection(httpClient, httpRequestOptions, getBaseUri());
    }

    @Override
    public ConnectionValidationResult validate(RequesterConnection connection) {
        return connection.validate(HttpRequest.builder()
                                       .uri(connection.getBaseUri())
                                       .method(HttpConstants.Method.GET)
                                       .build(), httpResponse -> {
            int statusCode =  httpResponse.getStatusCode();

            if (statusCode > 300 || statusCode < 200) {
                return ConnectionValidationResult.failure("Invalid status code: " + statusCode,
                                                          new Exception("Invalid status code: " + statusCode));
            } else {
                return ConnectionValidationResult.success();
            }
        }, exception -> ConnectionValidationResult.failure("There was an error while testing the connection", exception));
    }

}

==> http-requester-pure-java-0.1.1-alpha-sources.jar: requesterpj/internal/connection/provider/RequesterConnectionProvider.java <==
/*
 * (c) 2003-2022 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package requesterpj.internal.connection.provider;

import org.mule.runtime.api.connection.ConnectionValidationResult;
import org.mule.runtime.api.el.ExpressionLanguage;
import org.mule.runtime.extension.api.annotation.param.Optional;
import org.mule.runtime.extension.api.annotation.param.Parameter;
import org.mule.runtime.extension.api.annotation.param.display.DisplayName;
import org.mule.runtime.extension.api.annotation.param.display.Summary;
import org.mule.runtime.http.api.HttpConstants;
import org.mule.runtime.http.api.client.HttpClient;
import org.mule.runtime.http.api.client.HttpRequestOptions;
import org.mule.runtime.http.api.domain.message.request.HttpRequest;

import com.mulesoft.connectivity.rest.commons.api.connection.RestConnectionProvider;

import requesterpj.internal.connection.RequesterConnection;

public class RequesterConnectionProvider extends RestConnectionProvider<RequesterConnection> {

    @DisplayName("Base Uri")
    @Summary("Parameter base URI. Each instance or tenant gets its own base URI.")
    @Parameter
    @Optional
    private String baseUri;

    @Override public String getBaseUri() {
        return baseUri;
    }

    @Override
    protected RequesterConnection createConnection(HttpClient httpClient, HttpRequestOptions httpRequestOptions,
                                                   ExpressionLanguage expressionLanguage) {
        return new RequesterConnection(httpClient, httpRequestOptions, getBaseUri(), expressionLanguage);
    }

    @Override
    public ConnectionValidationResult validate(RequesterConnection connection) {
        return connection.validate(HttpRequest.builder()
                                       .uri(connection.getBaseUri())
                                       .method(HttpConstants.Method.GET)
                                       .build(), httpResponse -> {
            int statusCode =  httpResponse.getStatusCode();

            if (statusCode > 300 || statusCode < 200) {
                return ConnectionValidationResult.failure("Invalid status code: " + statusCode,
                                                          new Exception("Invalid status code: " + statusCode));
            } else {
                return ConnectionValidationResult.success();
            }
        }, exception -> ConnectionValidationResult.failure("There was an error while testing the connection", exception));
    }

}
